@@ -42,7 +42,7 @@ OPERATOR_MAP = {
 def build_segment(model, segment, attr):
     # Get the associated column for the initial path.
     path = segment.path.pop(0)
-    col = getattr(model, path)
+    col = model.__dict__[path]
 
     # Resolve the inner-most path segment.
     if segment.path:
@@ -71,7 +71,6 @@ def build_clause(query, attributes, model):
         seg.path[0:1] = attribute.path.split('.')
 
         # Construct the clause from the segment.
-        # import ipdb; ipdb.set_trace
         q = build_segment(model, seg, attribute)
 
         # Combine the segment with the last.
@@ -135,7 +134,6 @@ class ModelResource(object):
         elif self.request.query:
             # This is a list-access; use the query string and construct
             # a query object from it.
-            # import ipdb; ipdb.set_trace()
             query = parser.parse(self.request.query)
 
         # Determine if we need to filter the queryset in some way; and if so,
@@ -186,6 +184,9 @@ class ModelResource(object):
         if not authz.is_authorized(self.request.user, 'update', self, target):
             authz.unauthorized()
 
+        # Flush the target and expire attributes.
+        self.session.flush()
+
     def destroy(self):
         # Grab the existing target.
         target = self.read()
